@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -87,8 +87,7 @@ version_dialog (void)
   gchar *str[3];
   gint i,length;
   GList *glist;
-  GdkBitmap *mask;
-  GdkPixmap *pixmap;
+  GdkPixbuf *pixbuf;
   GtkTextBuffer *buffer;
   GtkTextIter where;
   GtkTreeIter iter,iter_parent;
@@ -119,7 +118,7 @@ const static gchar *authors =
 "    ryoma\n"
 "    And all Video maid users";
 /* XPM */
-static gchar *vmaid_xpm[] = {
+static const gchar *vmaid_xpm[] = {
 "32 32 16 1",
 "   c None",
 ".  c #000000",
@@ -322,16 +321,15 @@ static gchar *vmaid_xpm[] = {
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
                         G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  /* ja:ピクスマップ */
-  pixmap = gdk_pixmap_create_from_xpm_d (window->window,
-                                                    &mask, NULL, vmaid_xpm);
 
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, SPACING);
+  pixbuf = gdk_pixbuf_new_from_xpm_data (vmaid_xpm);
   gtk_box_pack_start (GTK_BOX (hbox0),
-                    gtk_image_new_from_pixmap (pixmap, mask), FALSE, FALSE, 0);
+                        gtk_image_new_from_pixbuf (pixbuf), FALSE, FALSE, 0);
+  g_object_unref (pixbuf);
   gtk_box_pack_start (GTK_BOX (hbox0),
                 gtk_label_new (VMAID_VERSION_NOTICE"\n"VMAID_COPYRIGHT_NOTICE),
                                                             FALSE, FALSE, 0);
